check

Function check 

pub fn check(json_path: &str) -> Result<()>
Validate a world and report its errors without building blobs.

json_path is used when it names an existing file; otherwise the world is discovered.