rm_at_path

Function rm_at_path 

pub fn rm_at_path(world_path: &str, name: &str) -> Result<()>
Remove the asset named name from world_path and rebuild.

Errors if name is not present. When it isn’t, the error message includes the known asset names from the world so the caller can suggest a fix.