run_editor

Function run_editor 

pub fn run_editor(
    json_path: Option<&str>,
    debug_port: Option<u16>,
) -> Result<()>
Editor entry point (cn editor). Compiles the authored world in memory, injects the editor HUD, and runs the world loop driven by the editor hook (plus the debug server when a port is given).