pub fn world_from_loaded(loaded: LoadedWorld) -> Result<World>Expand description
Compile a prepared world and assemble it into an in-memory World, ready to run without touching any blob files on disk.
pub fn world_from_loaded(loaded: LoadedWorld) -> Result<World>Compile a prepared world and assemble it into an in-memory World, ready to run without touching any blob files on disk.