pub fn build(json_path: Option<&str>) -> Result<()>
Compile a world to binary blobs and write world-lock.json.
world-lock.json
json_path is used when it names an existing file; otherwise the world is discovered.
json_path