pub fn run_editor(
json_path: Option<&str>,
debug_port: Option<u16>,
) -> Result<()>Expand description
Editor entry point (cn editor). Brings up a renderable world – building the
blobs first if they are missing, and falling back to an empty in-memory world
when there is nothing to load – injects the editor HUD, and runs the world
loop driven by the editor hook (plus the debug server when a port is given).